@@ -27,197 +27,194 @@
 /// Processor C++ wrapper
 
 #ifndef _ZBAR_H_
-# error "include zbar.h in your application, **not** zbar/Processor.h"
+#error "include zbar.h in your application, **not** zbar/Processor.h"
 #endif
 
 #include "Exception.h"
 #include "Image.h"
 
-namespace zbar {
-
+namespace zbar
+{
 /// high-level self-contained image processor.
 /// processes video and images for barcodes, optionally displaying
 /// images to a library owned output window
 
-class Processor {
- public:
+class Processor
+{
+public:
     /// value to pass for no timeout.
     static const int FOREVER = -1;
 
     /// constructor.
-    Processor (bool threaded = true,
-               const char *video_device = "",
-               bool enable_display = true)
+    Processor(bool threaded = true, const char *video_device = "",
+	      bool enable_display = true)
     {
-        _processor = zbar_processor_create(threaded);
-        if(!_processor)
-            throw std::bad_alloc();
-        init(video_device, enable_display);
+	_processor = zbar_processor_create(threaded);
+	if (!_processor)
+	    throw std::bad_alloc();
+	init(video_device, enable_display);
     }
 
-    ~Processor ()
+    ~Processor()
     {
-        zbar_processor_destroy(_processor);
+	zbar_processor_destroy(_processor);
     }
 
     /// cast to C processor object.
-    operator zbar_processor_t* ()
+    operator zbar_processor_t *()
     {
-        return(_processor);
+	return (_processor);
     }
 
     /// opens a video input device and/or prepares to display output.
     /// see zbar_processor_init()
-    void init (const char *video_device = "",
-               bool enable_display = true)
+    void init(const char *video_device = "", bool enable_display = true)
     {
-        if(zbar_processor_init(_processor, video_device, enable_display))
-            throw_exception(_processor);
+	if (zbar_processor_init(_processor, video_device, enable_display))
+	    throw_exception(_processor);
     }
 
     /// setup result handler callback.
     /// see zbar_processor_set_data_handler()
-    void set_handler (Image::Handler& handler)
+    void set_handler(Image::Handler &handler)
     {
-        zbar_processor_set_data_handler(_processor, handler, &handler);
+	zbar_processor_set_data_handler(_processor, handler, &handler);
     }
 
     /// set config for indicated symbology (0 for all) to specified value.
     /// @see zbar_processor_set_config()
     /// @since 0.4
-    int set_config (zbar_symbol_type_t symbology,
-                    zbar_config_t config,
-                    int value)
+    int set_config(zbar_symbol_type_t symbology, zbar_config_t config,
+		   int value)
     {
-        return(zbar_processor_set_config(_processor, symbology,
-                                          config, value));
+	return (
+	    zbar_processor_set_config(_processor, symbology, config, value));
     }
 
     /// set config parsed from configuration string.
     /// @see zbar_processor_parse_config()
     /// @since 0.4
-    int set_config (std::string cfgstr)
+    int set_config(std::string cfgstr)
     {
-        return(zbar_processor_parse_config(_processor, cfgstr.c_str()));
+	return (zbar_processor_parse_config(_processor, cfgstr.c_str()));
     }
 
     /// retrieve the current state of the output window.
     /// see zbar_processor_is_visible()
-    bool is_visible ()
+    bool is_visible()
     {
-        int rc = zbar_processor_is_visible(_processor);
-        if(rc < 0)
-            throw_exception(_processor);
-        return(rc != 0);
+	int rc = zbar_processor_is_visible(_processor);
+	if (rc < 0)
+	    throw_exception(_processor);
+	return (rc != 0);
     }
 
     /// show or hide the display window owned by the library.
     /// see zbar_processor_set_visible()
-    void set_visible (bool visible = true)
+    void set_visible(bool visible = true)
     {
-        if(zbar_processor_set_visible(_processor, visible) < 0)
-            throw_exception(_processor);
+	if (zbar_processor_set_visible(_processor, visible) < 0)
+	    throw_exception(_processor);
     }
 
     /// control the processor in free running video mode.
     /// see zbar_processor_set_active()
-    void set_active (bool active = true)
+    void set_active(bool active = true)
     {
-        if(zbar_processor_set_active(_processor, active) < 0)
-            throw_exception(_processor);
+	if (zbar_processor_set_active(_processor, active) < 0)
+	    throw_exception(_processor);
     }
 
     /// retrieve decode results for last scanned image.
     /// @see zbar_processor_get_results()
     /// @since 0.10
-    const SymbolSet get_results () const {
-        return(SymbolSet(zbar_processor_get_results(_processor)));
+    const SymbolSet get_results() const
+    {
+	return (SymbolSet(zbar_processor_get_results(_processor)));
     }
 
     /// wait for input to the display window from the user.
     /// see zbar_processor_user_wait()
-    int user_wait (int timeout = FOREVER)
+    int user_wait(int timeout = FOREVER)
     {
-        int rc = zbar_processor_user_wait(_processor, timeout);
-        if(rc < 0)
-            throw_exception(_processor);
-        return(rc);
+	int rc = zbar_processor_user_wait(_processor, timeout);
+	if (rc < 0)
+	    throw_exception(_processor);
+	return (rc);
     }
 
     /// process from the video stream until a result is available.
     /// see zbar_process_one()
-    void process_one (int timeout = FOREVER)
+    void process_one(int timeout = FOREVER)
     {
-        if(zbar_process_one(_processor, timeout) < 0)
-            throw_exception(_processor);
+	if (zbar_process_one(_processor, timeout) < 0)
+	    throw_exception(_processor);
     }
 
     /// process the provided image for barcodes.
     /// see zbar_process_image()
-    void process_image (Image& image)
+    void process_image(Image &image)
     {
-        if(zbar_process_image(_processor, image) < 0)
-            throw_exception(_processor);
+	if (zbar_process_image(_processor, image) < 0)
+	    throw_exception(_processor);
     }
 
     /// process the provided image for barcodes.
     /// see zbar_process_image()
-    Processor& operator<< (Image& image)
+    Processor &operator<<(Image &image)
     {
-        process_image(image);
-        return(*this);
+	process_image(image);
+	return (*this);
     }
 
     /// force specific input and output formats for debug/testing.
     /// see zbar_processor_force_format()
-    void force_format (unsigned long input_format,
-                       unsigned long output_format)
+    void force_format(unsigned long input_format, unsigned long output_format)
     {
-        if(zbar_processor_force_format(_processor, input_format,
-                                        output_format))
-            throw_exception(_processor);
+	if (zbar_processor_force_format(_processor, input_format,
+					output_format))
+	    throw_exception(_processor);
     }
 
     /// force specific input and output formats for debug/testing.
     /// see zbar_processor_force_format()
-    void force_format (std::string& input_format,
-                       std::string& output_format)
+    void force_format(std::string &input_format, std::string &output_format)
     {
-        unsigned long ifourcc = zbar_fourcc_parse(input_format.c_str());
-        unsigned long ofourcc = zbar_fourcc_parse(output_format.c_str());
-        if(zbar_processor_force_format(_processor, ifourcc, ofourcc))
-            throw_exception(_processor);
+	unsigned long ifourcc = zbar_fourcc_parse(input_format.c_str());
+	unsigned long ofourcc = zbar_fourcc_parse(output_format.c_str());
+	if (zbar_processor_force_format(_processor, ifourcc, ofourcc))
+	    throw_exception(_processor);
     }
 
     /// request a preferred size for the video image from the device.
     /// see zbar_processor_request_size()
     /// @since 0.6
-    void request_size (int width, int height)
+    void request_size(int width, int height)
     {
-        zbar_processor_request_size(_processor, width, height);
+	zbar_processor_request_size(_processor, width, height);
     }
 
     /// request a preferred driver interface version for debug/testing.
     /// see zbar_processor_request_interface()
     /// @since 0.6
-    void request_interface (int version)
+    void request_interface(int version)
     {
-        zbar_processor_request_interface(_processor, version);
+	zbar_processor_request_interface(_processor, version);
     }
 
     /// request a preferred I/O mode for debug/testing.
     /// see zbar_processor_request_iomode()
     /// @since 0.7
-    void request_iomode (int iomode)
+    void request_iomode(int iomode)
     {
-        if(zbar_processor_request_iomode(_processor, iomode))
-            throw_exception(_processor);
+	if (zbar_processor_request_iomode(_processor, iomode))
+	    throw_exception(_processor);
     }
 
- private:
+private:
     zbar_processor_t *_processor;
 };
 
-}
+} // namespace zbar
 
 #endif
